(* camlp4r *)
(***********************************************************************)
(*                                                                     *)
(*                             Camlp4                                  *)
(*                                                                     *)
(*        Daniel de Rauglaudre, projet Cristal, INRIA Rocquencourt     *)
(*                                                                     *)
(*  Copyright 1998 Institut National de Recherche en Informatique et   *)
(*  Automatique.  Distributed only by permission.                      *)
(*                                                                     *)
(***********************************************************************)

(* $Id: plexer.mli,v 1.13 1997/12/08 12:07:49 ddr Exp $ *)

(* Module [Plexer]: lexical analyzer *)

value make : unit -> Token.lexer;
    (* Some lexer provided. See the module [Token]. The tokens returned
       follow the Objective Caml and the righteous lexing rules.
       The meaning of the tokens are:
-      * [Tterm s] is the keyword [s].
-      * [Tlident s] is the identifier [s] starting with a lowercase letter.
-      * [Tuident s] is the identifier [s] starting with an uppercase letter.
-      * [Tint s] is an integer constant whose string source is [s].
-      * [Tfloat s] is a float constant whose string source is [s].
-      * [Tstring s] is the string constant [s].
-      * [Tchar c] is the character constant [c].
-      * [Tquotation t s] is a quotation named [t] holding the string [s].
-      * [Tantiquot t s] is an antiquotation named [t] holding the string [s].
-      * [Tlocate i s] is a location directive at position [i] holding [s].
-      * [Teoi] is the end of input.

       The lexer do not use global (mutable) variables: instantiations
       of [Plexer.make ()] do not perturb each other.  *)
